@@ -8,7 +8,7 @@
 	Windows, Linux, Mac Os X.
 
 **Description:**
-	This module defines units tests for :mod:`foundations.common` module.
+	Defines units tests for :mod:`foundations.common` module.
 
 **Others:**
 
@@ -25,6 +25,7 @@ from __future__ import unicode_literals
 import os
 import platform
 import sys
+
 if sys.version_info[:2] <= (2, 6):
 	import unittest2 as unittest
 else:
@@ -39,64 +40,51 @@ import foundations.common
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
 __status__ = "Production"
 
-__all__ = ["RESOURCES_DIRECTORY",
-		"LIBRARY",
-		"TEXT_FILE",
-		"UniqifyTestCase",
-		"OrderedUniqifyTestCase",
-		"PathExistsTestCase",
-		"GetFirstItemTestCase",
-		"GetLastItemTestCase",
-		"IsBinaryFileTestCase",
-		"RepeatTestCase",
-		"DependencyResolverTestCase",
-		"GetHostAddressTestCase"]
-
-RESOURCES_DIRECTORY = os.path.join(os.path.dirname(__file__), "resources")
-LIBRARIES_DIRECTORY = os.path.join(RESOURCES_DIRECTORY, "libraries")
-if platform.system() == "Windows" or platform.system() == "Microsoft":
-	LIBRARY = os.path.join(LIBRARIES_DIRECTORY, "freeImage/FreeImage.dll")
-elif platform.system() == "Darwin":
-	LIBRARY = os.path.join(LIBRARIES_DIRECTORY, "freeImage/libfreeimage.dylib")
-elif platform.system() == "Linux":
-	LIBRARY = os.path.join(LIBRARIES_DIRECTORY, "freeImage/libfreeimage.so")
-TEXT_FILE = os.path.join(RESOURCES_DIRECTORY, "loremIpsum.txt")
+__all__ = ["UniqifyTestCase",
+		   "OrderedUniqifyTestCase",
+		   "UnpackDefaultTestCase",
+		   "PathExistsTestCase",
+		   "FilterPathTestCase",
+		   "GetFirstItemTestCase",
+		   "GetLastItemTestCase",
+		   "RepeatTestCase",
+		   "DependencyResolverTestCase",
+		   "GetHostAddressTestCase"]
 
 #**********************************************************************************************************************
 #***	Module classes and definitions.
 #**********************************************************************************************************************
 class UniqifyTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.uniqify` definition units tests methods.
+	Defines :func:`foundations.common.uniqify` definition units tests methods.
 	"""
 
 	def testUniqify(self):
 		"""
-		This method tests :func:`foundations.common.uniqify` definition.
+		Tests :func:`foundations.common.uniqify` definition.
 		"""
 
 		sequence = ("A", "B", "B", "C")
 		self.assertListEqual(sorted(foundations.common.uniqify(sequence)), ["A", "B", "C"])
 		sequence = ((1, "A"), (2, "B"), (2, "B"), (3, "C"))
 		self.assertListEqual(sorted(foundations.common.uniqify(sequence)), [(1, "A"), (2, "B"), (3, "C")])
-		sequence = ({1 : "A"}, {1 : "A"}, {2 : "B"}, {3 : "C"})
-		self.assertListEqual(sorted(foundations.common.uniqify(sequence)), [{1 : "A"}, {2 : "B"}, {3 : "C"}])
-
+		sequence = ({1: "A"}, {1: "A"}, {2: "B"}, {3: "C"})
+		self.assertListEqual(sorted(foundations.common.uniqify(sequence)), [{1: "A"}, {2: "B"}, {3: "C"}])
 
 class OrderedUniqifyTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.orderedUniqify` definition units tests methods.
+	Defines :func:`foundations.common.orderedUniqify` definition units tests methods.
 	"""
 
 	def testOrderedUniqify(self):
 		"""
-		This method tests :func:`foundations.common.orderedUniqify` definition.
+		Tests :func:`foundations.common.orderedUniqify` definition.
 		"""
 
 		sequence = ("A", "B", "B", "C")
@@ -106,27 +94,27 @@ class OrderedUniqifyTestCase(unittest.TestCase):
 
 class UnpackDefaultTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.unpackDefault` definition units tests methods.
+	Defines :func:`foundations.common.unpackDefault` definition units tests methods.
 	"""
 
 	def testUnpackDefault(self):
 		"""
-		This method tests :func:`foundations.common.unpackDefault` definition.
+		Tests :func:`foundations.common.unpackDefault` definition.
 		"""
 
 		self.assertListEqual(list(foundations.common.unpackDefault((1,))), [1, None, None])
 		self.assertListEqual(list(foundations.common.unpackDefault((1, 2, 3, 4), length=3)), [1, 2, 3])
 		self.assertListEqual(list(foundations.common.unpackDefault((1, 2, 3, 4), length=5, default="Default")),
-							[1, 2, 3, 4, "Default"])
+							 [1, 2, 3, 4, "Default"])
 
 class PathExistsTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.pathExists` definition units tests methods.
+	Defines :func:`foundations.common.pathExists` definition units tests methods.
 	"""
 
 	def testPathExists(self):
 		"""
-		This method tests :func:`foundations.common.pathExists` definition.
+		Tests :func:`foundations.common.pathExists` definition.
 		"""
 
 		self.assertEqual(foundations.common.pathExists(None), False)
@@ -135,12 +123,12 @@ class PathExistsTestCase(unittest.TestCase):
 
 class FilterPathTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.filterPath` definition units tests methods.
+	Defines :func:`foundations.common.filterPath` definition units tests methods.
 	"""
 
 	def testFilterPath(self):
 		"""
-		This method tests :func:`foundations.common.filterPath` definition.
+		Tests :func:`foundations.common.filterPath` definition.
 		"""
 
 		self.assertEqual(foundations.common.filterPath(None), "")
@@ -148,12 +136,12 @@ class FilterPathTestCase(unittest.TestCase):
 
 class GetFirstItemTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.getFirstItem` definition units tests methods.
+	Defines :func:`foundations.common.getFirstItem` definition units tests methods.
 	"""
 
 	def testGetFirstItem(self):
 		"""
-		This method tests :func:`foundations.common.getFirstItem` definition.
+		Tests :func:`foundations.common.getFirstItem` definition.
 		"""
 
 		self.assertEqual(foundations.common.getFirstItem(None), None)
@@ -165,12 +153,12 @@ class GetFirstItemTestCase(unittest.TestCase):
 
 class GetLastItemTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.getLastItem` definition units tests methods.
+	Defines :func:`foundations.common.getLastItem` definition units tests methods.
 	"""
 
 	def testGetLastItem(self):
 		"""
-		This method tests :func:`foundations.common.getLastItem` definition.
+		Tests :func:`foundations.common.getLastItem` definition.
 		"""
 
 		self.assertEqual(foundations.common.getLastItem(None), None)
@@ -180,27 +168,14 @@ class GetLastItemTestCase(unittest.TestCase):
 		self.assertEqual(foundations.common.getLastItem(("Nemo",)), "Nemo")
 		self.assertEqual(foundations.common.getLastItem(("Nemo", "John", "Doe")), "Doe")
 
-class IsBinaryFileTestCase(unittest.TestCase):
-	"""
-	This class defines :func:`foundations.common.isBinaryFile` definition units tests methods.
-	"""
-
-	def testPathExists(self):
-		"""
-		This method tests :func:`foundations.common.isBinaryFile` definition.
-		"""
-
-		self.assertTrue(foundations.common.isBinaryFile(LIBRARY))
-		self.assertFalse(foundations.common.isBinaryFile(TEXT_FILE))
-
 class RepeatTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.isBinaryFile` definition units tests methods.
+	Defines :func:`foundations.common.repeat` definition units tests methods.
 	"""
 
 	def testRepeat(self):
 		"""
-		This method tests :func:`foundations.common.repeat` definition.
+		Tests :func:`foundations.common.repeat` definition.
 		"""
 
 		def foo(bar):
@@ -211,29 +186,29 @@ class RepeatTestCase(unittest.TestCase):
 
 class DependencyResolverTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.dependencyResolver` definition units tests methods.
+	Defines :func:`foundations.common.dependencyResolver` definition units tests methods.
 	"""
 
 	def testDependencyResolver(self):
 		"""
-		This method tests :func:`foundations.common.dependencyResolver` definition.
+		Tests :func:`foundations.common.dependencyResolver` definition.
 		"""
 
-		dependencies = {"c" : ("a", "b"),
-						"d" : ("c",),
-						"f" : ("b",)}
+		dependencies = {"c": ("a", "b"),
+						"d": ("c",),
+						"f": ("b",)}
 
 		self.assertEquals(foundations.common.dependencyResolver(dependencies),
-						[set(["a", "b"]), set(["c", "f"]), set(["d"])])
+						  [set(["a", "b"]), set(["c", "f"]), set(["d"])])
 
 class GetHostAddressTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.getHostAddress` definition units tests methods.
+	Defines :func:`foundations.common.getHostAddress` definition units tests methods.
 	"""
 
 	def testGetHostAddress(self):
 		"""
-		This method tests :func:`foundations.common.getHostAddress` definition.
+		Tests :func:`foundations.common.getHostAddress` definition.
 		"""
 
 		self.assertIsInstance(foundations.common.getHostAddress(), unicode)
@@ -241,4 +216,5 @@ class GetHostAddressTestCase(unittest.TestCase):
 
 if __name__ == "__main__":
 	import foundations.tests.utilities
+
 	unittest.main()
