@@ -8,7 +8,7 @@
 	Windows, Linux, Mac Os X.
 
 **Description:**
-	This module defines units tests for :mod:`foundations.environment` module.
+	Defines units tests for :mod:`foundations.environment` module.
 
 **Others:**
 
@@ -25,10 +25,12 @@ from __future__ import unicode_literals
 import os
 import platform
 import sys
+
 if sys.version_info[:2] <= (2, 6):
 	import unittest2 as unittest
 else:
 	import unittest
+import tempfile
 
 #**********************************************************************************************************************
 #***	Internal imports.
@@ -40,13 +42,14 @@ from foundations.environment import Environment
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
 __status__ = "Production"
 
 __all__ = ["EnvironmentTestCase",
+		"GetTemporaryDirectoryTestCase",
 		"GetSystemApplicationDataDirectoryTestCase",
 		"GetUserApplicationDataDirectoryTestCase", ]
 
@@ -55,12 +58,12 @@ __all__ = ["EnvironmentTestCase",
 #**********************************************************************************************************************
 class EnvironmentTestCase(unittest.TestCase):
 	"""
-	This class defines :class:`foundations.environment.Environment` class units tests methods.
+	Defines :class:`foundations.environment.Environment` class units tests methods.
 	"""
 
 	def testRequiredAttributes(self):
 		"""
-		This method tests presence of required attributes.
+		Tests presence of required attributes.
 		"""
 
 		requiredAttributes = ("variables",)
@@ -70,7 +73,7 @@ class EnvironmentTestCase(unittest.TestCase):
 
 	def testRequiredMethods(self):
 		"""
-		This method tests presence of required methods.
+		Tests presence of required methods.
 		"""
 
 		requiredMethods = ("getValues",
@@ -83,7 +86,7 @@ class EnvironmentTestCase(unittest.TestCase):
 
 	def testGetValues(self):
 		"""
-		This method tests :meth:`foundations.environment.Environment.getValues` method.
+		Tests :meth:`foundations.environment.Environment.getValues` method.
 		"""
 
 		if platform.system() == "Windows" or platform.system() == "Microsoft":
@@ -104,7 +107,7 @@ class EnvironmentTestCase(unittest.TestCase):
 
 	def testSetValues(self):
 		"""
-		This method tests :meth:`foundations.environment.Environment.setValues` method.
+		Tests :meth:`foundations.environment.Environment.setValues` method.
 		"""
 
 		environment = Environment()
@@ -116,7 +119,7 @@ class EnvironmentTestCase(unittest.TestCase):
 
 	def testGetValue(self):
 		"""
-		This method tests :meth:`foundations.environment.Environment.getValue` method.
+		Tests :meth:`foundations.environment.Environment.getValue` method.
 		"""
 
 		if platform.system() == "Windows" or platform.system() == "Microsoft":
@@ -133,7 +136,7 @@ class EnvironmentTestCase(unittest.TestCase):
 
 	def testSetValue(self):
 		"""
-		This method tests :meth:`foundations.environment.Environment.setValue` method.
+		Tests :meth:`foundations.environment.Environment.setValue` method.
 		"""
 
 		environment = Environment()
@@ -141,14 +144,29 @@ class EnvironmentTestCase(unittest.TestCase):
 		self.assertIn("JANE", os.environ)
 		self.assertEqual(environment.getValue("JANE"), "DOE")
 
-class GetSystemApplicationDataDirectoryTestCase(unittest.TestCase):
+class GetTemporaryDirectoryTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.getSystemApplicationDataDirectory` definition units tests methods.
+	Defines :func:`foundations.common.getTemporaryDirectory` definition units tests methods.
 	"""
 
 	def testGetSystemApplicationDataDirectory(self):
 		"""
-		This method tests :func:`foundations.common.getSystemApplicationDataDirectory` definition.
+		Tests :func:`foundations.common.getTemporaryDirectory` definition.
+		"""
+
+		path = foundations.environment.getTemporaryDirectory()
+		self.assertIsInstance(path, unicode)
+		self.assertTrue(os.path.exists(path))
+		self.assertEqual(path, tempfile.gettempdir())
+
+class GetSystemApplicationDataDirectoryTestCase(unittest.TestCase):
+	"""
+	Defines :func:`foundations.common.getSystemApplicationDataDirectory` definition units tests methods.
+	"""
+
+	def testGetSystemApplicationDataDirectory(self):
+		"""
+		Tests :func:`foundations.common.getSystemApplicationDataDirectory` definition.
 		"""
 
 		path = foundations.environment.getSystemApplicationDataDirectory()
@@ -157,12 +175,12 @@ class GetSystemApplicationDataDirectoryTestCase(unittest.TestCase):
 
 class GetUserApplicationDataDirectoryTestCase(unittest.TestCase):
 	"""
-	This class defines :func:`foundations.common.getUserApplicationDataDirectory` definition units tests methods.
+	Defines :func:`foundations.common.getUserApplicationDataDirectory` definition units tests methods.
 	"""
 
 	def testGetUserApplicationDataDirectory(self):
 		"""
-		This method tests :func:`foundations.common.getUserApplicationDataDirectory` definition.
+		Tests :func:`foundations.common.getUserApplicationDataDirectory` definition.
 		"""
 
 		path = foundations.environment.getUserApplicationDataDirectory()
