@@ -8,7 +8,7 @@
 	Windows, Linux, Mac Os X.
 
 **Description:**
-	This module defines **Foundations** package ui common utilities objects.
+	Defines **Foundations** package ui common utilities objects.
 
 **Others:**
 
@@ -38,7 +38,7 @@ import foundations.verbose
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
@@ -56,11 +56,14 @@ DEFAULT_UI_FILE = os.path.join(RESOURCES_DIRECTORY, "QWidget.ui")
 #**********************************************************************************************************************
 def centerWidgetOnScreen(widget, screen=None):
 	"""
-	This definition centers the given Widget on the screen.
+	Centers the given Widget on the screen.
 
-	:param widget: Current Widget. ( QWidget )
-	:param screen: Screen used for centering. ( Integer )
-	:return: Definition success. ( Boolean )
+	:param widget: Current Widget.
+	:type widget: QWidget
+	:param screen: Screen used for centering.
+	:type screen: int
+	:return: Definition success.
+	:rtype: bool
 	"""
 
 	screen = screen and screen or QApplication.desktop().primaryScreen()
@@ -71,13 +74,17 @@ def centerWidgetOnScreen(widget, screen=None):
 
 def QWidgetFactory(uiFile=None, *args, **kwargs):
 	"""
-	This definition is a class factory creating `QWidget <http://doc.qt.nokia.com/qwidget.html>`_ classes
+	Defines a class factory creating `QWidget <http://doc.qt.nokia.com/qwidget.html>`_ classes
 	using given ui file.
 
-	:param uiFile: Ui file. ( String )
-	:param \*args: Arguments. ( \* )
-	:param \*\*kwargs: Keywords arguments. ( \*\* )
-	:return: QWidget class. ( QWidget )
+	:param uiFile: Ui file.
+	:type uiFile: unicode
+	:param \*args: Arguments.
+	:type \*args: \*
+	:param \*\*kwargs: Keywords arguments.
+	:type \*\*kwargs: \*\*
+	:return: QWidget class.
+	:rtype: QWidget
 	"""
 
 	file = uiFile or DEFAULT_UI_FILE
@@ -88,15 +95,17 @@ def QWidgetFactory(uiFile=None, *args, **kwargs):
 
 	class QWidget(Form, Base):
 		"""
-		This class is built by the :def:`QWidgetFactory` definition.
+		Derives from :def:`QWidgetFactory` class factory definition.
 		"""
 
 		def __init__(self, *args, **kwargs):
 			"""
-			This method initializes the class.
+			Initializes the class.
 
-			:param \*args: Arguments. ( \* )
-			:param \*\*kwargs: Keywords arguments. ( \*\* )
+			:param \*args: Arguments.
+			:type \*args: \*
+			:param \*\*kwargs: Keywords arguments.
+			:type \*\*kwargs: \*\*
 			"""
 
 			LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
@@ -115,9 +124,10 @@ def QWidgetFactory(uiFile=None, *args, **kwargs):
 		@property
 		def uiFile(self):
 			"""
-			This method is the property for **self.__uiFile** attribute.
+			Property for **self.__uiFile** attribute.
 
-			:return: self.__uiFile. ( String )
+			:return: self.__uiFile.
+			:rtype: unicode
 			"""
 
 			return self.__uiFile
@@ -126,9 +136,10 @@ def QWidgetFactory(uiFile=None, *args, **kwargs):
 		@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 		def uiFile(self, value):
 			"""
-			This method is the setter method for **self.__uiFile** attribute.
+			Setter for **self.__uiFile** attribute.
 
-			:param value: Attribute value. ( String )
+			:param value: Attribute value.
+			:type value: unicode
 			"""
 
 			raise foundations.exceptions.ProgrammingError("{0} | '{1}' attribute is read only!".format(
@@ -138,7 +149,7 @@ def QWidgetFactory(uiFile=None, *args, **kwargs):
 		@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 		def uiFile(self):
 			"""
-			This method is the deleter method for **self.__uiFile** attribute.
+			Deleter for **self.__uiFile** attribute.
 			"""
 
 			raise foundations.exceptions.ProgrammingError("{0} | '{1}' attribute is not deletable!".format(
@@ -149,9 +160,10 @@ def QWidgetFactory(uiFile=None, *args, **kwargs):
 		#******************************************************************************************************************
 		def show(self, setGeometry=True):
 			"""
-			This method reimplements the :meth:`QWidget.show` method.
+			Reimplements the :meth:`QWidget.show` method.
 
-			:param setGeometry: Set geometry. ( Boolean )
+			:param setGeometry: Set geometry.
+			:type setGeometry: bool
 			"""
 
 			if not setGeometry:
@@ -170,9 +182,10 @@ def QWidgetFactory(uiFile=None, *args, **kwargs):
 
 		def closeEvent(self, event):
 			"""
-			This method reimplements the :meth:`QWidget.closeEvent` method.
+			Reimplements the :meth:`QWidget.closeEvent` method.
 
-			:param event: QEvent. ( QEvent )
+			:param event: QEvent.
+			:type event: QEvent
 			"""
 
 			self.__geometry = self.saveGeometry()
